@@ -59,6 +59,10 @@ class AsyncAnalytics:
         **kwargs:
             Additional parameters to be passed to the
             :obj:`httpx.Client` constructor.
+
+    Attributes:
+        secrets:
+            A :obj:`Secrets` object representing your project secrets.
     """
 
     __slots__ = (
@@ -212,8 +216,7 @@ class AsyncAnalytics:
 
         r = await self._session.post(self.secrets.token_uri, data=data, headers=headers)
         if r.is_error:
-            error = r.json()["error"]
-            raise errors.AuthenticationError(error["code"], error["message"])
+            raise errors.AuthenticationError(**r.json())
 
         return Tokens.from_data(r.json())
 
